# OrgMiner

*Note: You are viewing a legacy project.*

This project is a legacy version of [OrdinoR](https://github.com/roy-jingyang/OrdinoR). 

Please visit the current project [documentation](https://ordinor.readthedocs.io/) for up-to-date information.

##### Further Notice
This legacy project corresponds to a Python package named ``orgminer`` on [PyPI](https://pypi.org/).
You will still find the package ``orgminer`` on PyPI but only as a dummy package.

Attempting to install the legacy package ``pip install orgminer`` has no harm. You will have ``ordinor`` installed ([pypi](https://pypi.org/project/ordinor/)), which corresponds to the current active package from our research project.
